@@ -1,21 +1,19 @@
 /*
-  SPDX-FileCopyrightText: 2024 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2024-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "activitiesmanager.h"
 #include "accountactivities.h"
-#include "kaddressbook_activities_debug.h"
+// #include "kaddressbook_activities_debug.h"
 #include "ldapactivities.h"
 
-#include <PimCommonActivities/ActivitiesBaseManager>
 #include <PlasmaActivities/Consumer>
 
 ActivitiesManager::ActivitiesManager(QObject *parent)
     : PimCommonActivities::ActivitiesBaseManager{parent}
     , mLdapActivities(new LdapActivities(this))
-    , mActivitiesConsumer(new KActivities::Consumer(this))
     , mAccountActivities(new AccountActivities(this))
 {
     connect(this, &ActivitiesManager::activitiesChanged, this, [this]() {
@@ -32,19 +30,6 @@ ActivitiesManager *ActivitiesManager::self()
     return &s_self;
 }
 
-bool ActivitiesManager::enabled() const
-{
-    return mEnabled;
-}
-
-void ActivitiesManager::setEnabled(bool newEnabled)
-{
-    if (mEnabled != newEnabled) {
-        mEnabled = newEnabled;
-        Q_EMIT activitiesChanged();
-    }
-}
-
 LdapActivities *ActivitiesManager::ldapActivities() const
 {
     return mLdapActivities;
